==> fheroes2_1.1.8+dfsg.orig.tar.xz: fheroes2-1.1.8/docs/README_android.md <==
# Android Port of [fheroes2](README.md) Project

## Installation

Install the fheroes2.apk to your device running Android. You need to have set the necessary permissions on your device to
do this.

fheroes2 requires the data files from the original Heroes of Might and Magic II. If you do not have the original game you
can download a demo version of the game from <https://archive.org/download/HeroesofMightandMagicIITheSuccessionWars_1020/h2demo.zip>

If you already have a legally purchased copy of the original game, then put the directories "ANIM", "DATA", "MAPS" and "MUSIC"
from your original Heroes of Might and Magic II installation into a ZIP archive and copy this archive to your Android device.

Run the "fh2 Toolset" app, press the "Extract HoMM2 assets" button and select either the ZIP archive of the demo version or the
ZIP archive created by you in the previous step to extract the assets of the original game to the proper place.

Depending on your version of Heroes 2, the music files that need to be placed in the "MUSIC" directory can either be on your
original CD or in the installation folder (GOG and Ubisoft).

Ingame cinematics are supported by fheroes2 and for these to be supported it is necessary to have them in the "ANIM" folder.
Depending on your original version of Heroes 2 they can either be found on your CD, disc image or in a folder named "anim" in
your Heroes 2 installation directory.

## Controls

To simulate a right-click to get info on various items, you need to first touch and keep touching on the item of interest
and then touch anywhere else on the screen. While holding the second finger, you can remove the first one from the screen
and keep viewing the information on the item.

By default normal adventure map scrolling on the borders of the screen is disabled. To pane the viewing area around you
need to press anywhere on the adventure map and slide around to change where you are viewing.

During combat, actions (such as moving, attacking, or casting a spell) performed using the touchpad/touchscreen must be
confirmed. The first touch event just places the cursor at the touch point, displaying information about the action being
performed (the cell/cells to be moved to, the angle of attack and the cells subject to attack, the spell and the cells
affected by this spell, potential damage, and so on). The second touch event is confirmatory, and performs the corresponding
action if and only if this action exactly corresponds to the action that the first touch demonstrates.

To make it easier to select the angle of attack on touchscreens, you can "draw" the angle by swiping your finger from the cell you
intend to attack from, to the cell occupied by the enemy unit. Next, you should remove your finger from the screen, double-check
your planned attack, and then confirm the action by touching the target cell with your finger again.

## Android Specific Notes

Fullscreen is enabled by default. To have the info bar with the clock visible you can disable fullscreen mode within the
main menu settings under "Graphics".

The minimum supported Android version is 5.1.

==> fheroes2_1.1.11+dfsg.orig.tar.xz: fheroes2-1.1.11+dfsg/docs/README_android.md <==
# Android Port of [fheroes2](README.md) Project

## Installation

Install the fheroes2.apk to your device running Android. You need to have set the necessary permissions on your device to
do this.

fheroes2 requires the data files from the original Heroes of Might and Magic II. If you do not have the original game you
can download a demo version of the game from <https://archive.org/download/HeroesofMightandMagicIITheSuccessionWars_1020/h2demo.zip>

If you already have a legally purchased copy of the original game, then put the directories "ANIM", "DATA", "MAPS" and "MUSIC"
from your original Heroes of Might and Magic II installation into a ZIP archive and copy this archive to your Android device.

Run the "fh2 Toolset" app, press the "Extract HoMM2 assets" button and select either the ZIP archive of the demo version or the
ZIP archive created by you in the previous step to extract the assets of the original game to the proper place.

Depending on your version of Heroes 2, the music files that need to be placed in the "MUSIC" directory can either be on your
original CD or in the installation folder (GOG and Ubisoft).

Ingame cinematics are supported by fheroes2 and for these to be supported it is necessary to have them in the "ANIM" folder.
Depending on your original version of Heroes 2 they can either be found on your CD, disc image or in a folder named "anim" in
your Heroes 2 installation directory.

## Controls

To simulate a right-click to get info on various items, you need to first touch and keep touching on the item of interest
and then touch anywhere else on the screen. While holding the second finger, you can remove the first one from the screen
and keep viewing the information on the item.

By default normal adventure map scrolling on the borders of the screen is disabled. To pan the viewing area around you
need to press anywhere on the adventure map and slide around to change where you are viewing.

During combat, actions (such as moving, attacking, or casting a spell) performed using the touchpad/touchscreen must be
confirmed. The first touch event just places the cursor at the touch point, displaying information about the action being
performed (the cell/cells to be moved to, the angle of attack and the cells subject to attack, the spell and the cells
affected by this spell, potential damage, and so on). The second touch event is confirmatory, and performs the corresponding
action if and only if this action exactly corresponds to the action that the first touch demonstrates.

To make it easier to select the angle of attack on touchscreens, you can "draw" the angle by swiping your finger from the cell you
intend to attack from, to the cell occupied by the enemy unit. Next, you should remove your finger from the screen, double-check
your planned attack, and then confirm the action by touching the target cell with your finger again.

## Android Specific Notes

Fullscreen is enabled by default. To have the info bar with the clock visible you can disable fullscreen mode within the
main menu settings under "Graphics".

The minimum supported Android version is 5.1.
